@@ -5,7 +5,7 @@ use utf8;
 
 BEGIN {
 	$Web::ID::SAN::URI::AUTHORITY = 'cpan:TOBYINK';
-	$Web::ID::SAN::URI::VERSION   = '1.926';
+	$Web::ID::SAN::URI::VERSION   = '1.927';
 }
 
 use Web::ID::Types -types;
@@ -20,7 +20,7 @@ has '+type' => (default => 'uniformResourceIdentifier');
 override uri_object => sub
 {
 	my ($self) = @_;
-	return Uri->new($self->value);
+	return Uri->coerce($self->value);
 };
 
 around _build_model => sub
